import{_t as r,lt as t,n as e,yt as o}from"./render-cqdoDfd9.js";import{t as l}from"./TextField-CbQ6hH_9.js";var a=o(r(),1),s=t(),i=a.forwardRef(({label:r,value:t,onChange:o,error:a,helperText:i,sx:n={},...p},x)=>{const{direction:f}=e();return(0,s.jsx)(l,{ref:x,label:r,value:t,onChange:o,error:a,helperText:i,required:!0,sx:{...n,label:{right:"rtl"===f?"25px":"auto",left:"rtl"===f?"auto":0,"&.MuiInputLabel-shrink":{right:"rtl"===f?"30px":"auto",transformOrigin:"rtl"===f?"top right":"top left",left:"rtl"===f?"auto":0}}},slotProps:{formHelperText:{sx:{color:"errorText.main",marginLeft:0}}},...p,dir:f})});export{i as t};