import{A as t,O as a,W as s,_t as e,gt as o,lt as n,mt as i,pt as r,yt as l}from"./render-cqdoDfd9.js";function c(t){return i("MuiDialogActions",t)}s("MuiDialogActions",["root","spacing"]);var p=l(e()),g=n(),d=t=>{const{classes:a,disableSpacing:s}=t;return r({root:["root",!s&&"spacing"]},c,a)},u=t("div",{name:"MuiDialogActions",slot:"Root",overridesResolver:(t,a)=>{const{ownerState:s}=t;return[a.root,!s.disableSpacing&&a.spacing]}})({display:"flex",alignItems:"center",padding:8,justifyContent:"flex-end",flex:"0 0 auto",variants:[{props:({ownerState:t})=>!t.disableSpacing,style:{"& > :not(style) ~ :not(style)":{marginLeft:8}}}]}),f=p.forwardRef(function(t,s){const e=a({props:t,name:"MuiDialogActions"}),{className:n,disableSpacing:i=!1,...r}=e,l={...e,disableSpacing:i};return(0,g.jsx)(u,{className:o(d(l).root,n),ownerState:l,ref:s,...r})});export{f as t};