import{lt as t,n as e}from"./render-cqdoDfd9.js";import{t as r}from"./Box-pvlRBLzs.js";import{t as n}from"./Container-DQi3l0z9.js";import{t as o}from"./Typography-8v555lWC.js";import{t as a}from"./Button-D-nJohaT.js";var i=t(),s=({content:t,onDelete:s,onCancel:l})=>{const{localeMessages:c}=e();return(0,i.jsxs)(n,{sx:{padding:4,textAlign:"center"},children:[(0,i.jsx)(o,{variant:"h6",gutterBottom:!0,children:c.delete_content_confirmation.replace("CONTENT_TITLE",t.title)}),(0,i.jsxs)(r,{sx:{marginTop:2},children:[(0,i.jsx)(a,{variant:"contained",color:"error",onClick:()=>s(t.id),sx:{marginRight:2},children:c.delete}),(0,i.jsx)(a,{variant:"outlined",onClick:l,children:c.cancel})]})]})};export{s as default};