{% load i18n %}
{% with brand_color="#636eec" %}
<html>
    <head>
        <meta name="viewport" content="width=device-width, initial-scale=1.0" />
        <style>
            body {
                margin: 0;
                padding: 0;
            }
            .color-brand {
                color: {{ brand_color }};
            }
            .bg-brand {
                background-color: {{ brand_color }};
                color: #fff !important;
            }
            .border-brand {
                border-color: {{ brand_color }};
            }
            .background {
                padding: 10px;
                width: 100%;
                box-sizing: border-box;
                font-family: Helvetica, Arial, sans-serif;
                line-height: 1.8;
                font-size: 15px;
            }

            .locale {
                {% get_current_language_bidi as IS_RTL %}
                {% if IS_RTL %}
                    direction: rtl;
                    text-align: right;
                {% else %}
                    direction: ltr;
                    text-align: left;
                {% endif %}
            }

            @media screen and (max-width: 480px) {
                .mobile-content {
                    box-sizing: border-box;
                    width: 100% !important;
                    padding: 25px 20px !important;
                }
            }

            @media screen and (min-width: 481px) and (max-width: 850px) {
                .mobile-content {
                    box-sizing: border-box;
                    padding: 25px 20px !important;
                    width: 100% !important;
                }
            }
            @media screen and (min-width: 851px) {
                .mobile-content {
                    box-sizing: border-box;
                    width: 800px !important;
                    max-width: 800px !important;
                    margin: 20px auto;
                    padding: 40px 45px 20px !important;
                    border-radius: 8px;
                    border: 1px solid #cbcbcb58;
                }
            }
            img {
                max-width: 100%;
                height: auto;
                border-radius: 10px;
            }
            blockquote {
                {% if IS_RTL %}
                    border-right: 4px solid #e0e0e0;
                    border-left: none;
                {% else %}
                    border-left: 4px solid #e0e0e0;
                    border-right: none;
                {% endif %}
                margin: 0px !important;
                padding: 0 16px;
            }
            .email-title {
                margin: 0 0 30px;
                text-align: center;
                border-bottom: 2px solid #d8d9ee;
                padding-bottom: 25px;
                line-height: 1.35;
                font-size: 24px;
            }
            .email-subtitle {
                margin: 20px 0 10px;
                font-size: 18px;
            }
            .email-paragraph {
                font-size: 15px;
                margin: 0 0 16px;
            }
            .email-cover-wrap {
                margin: 0 0 40px;
            }
            .email-cover {
                width: 100%;
                max-width: 100%;
                height: auto;
                display: block;
                border-radius: 6px;
            }
            .email-cta-wrap {
                text-align: center;
                margin: 24px 0;
            }
            .email-cta {
                display: inline-block;
                padding: 12px 24px;
                text-decoration: none;
                border-radius: 5px;
                font-weight: 400;
                font-size: 15px;
                border: 1px solid rgba(31, 35, 64, 0.18);
            }
            .email-panel {
                padding: 20px;
                border-radius: 5px;
                margin: 24px 0;
            }
            .email-panel.border-brand {
                border-left: 4px solid;
            }
            .email-code-box {
                padding: 15px;
                border-radius: 4px;
                border: 1px dashed #6c757d;
                text-align: center;
            }
            .email-divider-note {
                margin-top: 30px;
                padding-top: 20px;
                border-top: 1px solid #e9ecef;
                font-size: 14px;
                color: #6c757d;
            }
            .email-muted-note {
                font-size: 14px;
                color: #7f8c8d;
                text-align: center;
                margin-top: 50px;
            }
            .email-signoff {
                margin-top: 24px;
            }
            .email-signoff.centered {
                text-align: center;
            }
            .email-org-name {
                font-weight: bold;
                font-size: 18px;
                margin: 0;
            }
            .email-list {
                margin: 0 0 16px;
                padding-left: 20px;
                font-size: 15px;
            }
            .email-list li {
                margin-bottom: 6px;
            }
            .footer {
                margin-top: 40px;
                padding: 40px;
                border-top: 1px solid #e9ecef;
                font-size: 14px;
                background-color: #9ca0a316;
            }
            .footer .mobile-content {
                border: 0;
                margin: 0 auto;
                padding: 0 10px !important;
                width: 100% !important;
            }
            {% block extra_styles %}{% endblock %}
        </style>
    </head>
<body>
    <div class="background">
        <div class="mobile-content locale">
            {% block content %}{% endblock %}
        </div>
        {% block footer %}{% endblock %}
    </div>
</body>
</html>
{% endwith %}
