.tiptap :first-child{margin-top:0}.tiptap img{display:inline}.tiptap [data-resize-handle]{z-index:10;background:#00000080;border:1px solid #fffc;border-radius:2px;position:absolute}.tiptap [data-resize-handle]:hover{background:#000c}.tiptap [data-resize-handle][data-resize-handle=top-left],.tiptap [data-resize-handle][data-resize-handle=top-right],.tiptap [data-resize-handle][data-resize-handle=bottom-left],.tiptap [data-resize-handle][data-resize-handle=bottom-right]{width:8px;height:8px}.tiptap [data-resize-handle][data-resize-handle=top-left]{cursor:nwse-resize;top:-4px;left:-4px}.tiptap [data-resize-handle][data-resize-handle=top-right]{cursor:nesw-resize;top:-4px;right:-4px}.tiptap [data-resize-handle][data-resize-handle=bottom-left]{cursor:nesw-resize;bottom:-4px;left:-4px}.tiptap [data-resize-handle][data-resize-handle=bottom-right]{cursor:nwse-resize;bottom:-4px;right:-4px}.tiptap [data-resize-handle][data-resize-handle=top],.tiptap [data-resize-handle][data-resize-handle=bottom]{height:6px;left:8px;right:8px}.tiptap [data-resize-handle][data-resize-handle=top]{cursor:ns-resize;top:-3px}.tiptap [data-resize-handle][data-resize-handle=bottom]{cursor:ns-resize;bottom:-3px}.tiptap [data-resize-handle][data-resize-handle=left],.tiptap [data-resize-handle][data-resize-handle=right]{width:6px;top:8px;bottom:8px}.tiptap [data-resize-handle][data-resize-handle=left]{cursor:ew-resize;left:-3px}.tiptap [data-resize-handle][data-resize-handle=right]{cursor:ew-resize;right:-3px}.tiptap [data-resize-state=true] [data-resize-wrapper]{border-radius:.125rem;outline:1px solid #00000040}
