import{F as e,G as a,Q as s,U as t,W as r,X as o,_t as m,ct as n,gt as d,ht as l,lt as u,yt as f}from"./render-cqdoDfd9.js";var c=f(m()),h=u();var i=r("MuiBox",["root"]),N=function(e={}){const{themeId:t,defaultTheme:r,defaultClassName:m="MuiBox-root",generateClassName:l}=e,u=n("div",{shouldForwardProp:e=>"theme"!==e&&"sx"!==e&&"as"!==e})(s);return c.forwardRef(function(e,s){const n=a(r),{className:f,component:c="div",...i}=o(e);return(0,h.jsx)(u,{as:c,ref:s,className:d(f,l?l(m):m),theme:t&&n[t]||n,...i})})}({themeId:t,defaultTheme:e(),defaultClassName:i.root,generateClassName:l.generate});export{N as t};