
{% load static %}
{% load i18n %}
<!doctype html>
<html lang="en">
  <head>
    
    
    {% get_current_language_bidi as IS_RTL %}
    {{ appContext | json_script:"app-context" }}
    {% block head_script %}{% endblock %}
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <link rel="icon" type="image/png" href="{% static 'logo.png' %}" />
    <title>{% block title %}{{ page_title }}{% endblock %}</title>
  </head>

  <body {% if IS_RTL %}dir="rtl"{% endif %}>
    <div id="root">
    </div>
  </body>
</html>
