{% load static %}{% load i18n %}{% get_current_language_bidi as IS_RTL %}<!doctype html>
<html lang="en" dir="{% block direction %}{% if IS_RTL %}rtl{% else %}ltr{% endif %}{% endblock %}">
  <head>
    
    
    <script>
        localStorage.setItem('activeOrganizationId', '{{ activeOrganizationId | escapejs }}');
    </script>
    {% if appContext.sidebarCustomComponent.styleUrl %}
        <link rel="stylesheet" href="{{ appContext.sidebarCustomComponent.styleUrl }}">
    {% endif %}
    {% if appContext.sidebarCustomComponent.scriptUrl %}
        <script src="{{ appContext.sidebarCustomComponent.scriptUrl }}" type="module"></script>
    {% endif %}
    {{ appContext | json_script:"app-context" }}
    {% block extra_head %}{% endblock %}
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <link rel="icon" type="image/png" href="{% if favicon %}{{ favicon }}{% else %}{% static 'logo.png' %}{% endif %}" />
    <title>{% block title %}{{ page_title }}{% endblock %}</title>
  </head>

  <body>
    <div id="root"></div>

  </body>
</html>
