{% extends "personalised/base.html" %}

{% block head_script %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-cqdoDfd9.js">
    <link rel="modulepreload" crossorigin href="/static/assets/modulepreload-polyfill-DgzdhEGd.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Alert-BpUkH7Nx.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Box-pvlRBLzs.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-D-nJohaT.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Typography-8v555lWC.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Layout-Bjk0lf1S.js">
    <script type="module" crossorigin src="/static/assets/command_result-BldmS9ga.js"></script>
    <script>
        (() => {
            const appContextScript = document.getElementById('app-context');
            if (!appContextScript) {
                return;
            }

            try {
                const appContext = JSON.parse(appContextScript.textContent || '{}');
                if (appContext.closeWindow === true) {
                    window.setTimeout(() => {
                        window.close();
                    }, 1200);
                }
            } catch (_) {
                return;
            }
        })();
    </script>
{% endblock %}
