import{lt as r}from"./render-cqdoDfd9.js";import{c as o}from"./Paper-DtiadJnq.js";var a=o((0,r().jsx)("path",{d:"M5 13.18v4L12 21l7-3.82v-4L12 17zM12 3 1 9l11 6 9-4.91V17h2V9z"}),"School");export{a as t};