{% extends "personalised/base.html" %}

{% block head_script %}
    <style>
        @media print {
            @page {
                size: A4 landscape;
                margin: 0;
            }
            body {
                padding: 0;
                margin: 0;
            }
        }
    </style>
    <link rel="modulepreload" crossorigin href="/static/assets/render-cqdoDfd9.js">
    <link rel="modulepreload" crossorigin href="/static/assets/modulepreload-polyfill-DgzdhEGd.js">
    <link rel="modulepreload" crossorigin href="/static/assets/WorkspacePremium-BuOxKl4p.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Alert-BpUkH7Nx.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Box-pvlRBLzs.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Grid-BiwBFfYj.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Paper-DtiadJnq.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Typography-8v555lWC.js">
    <script type="module" crossorigin src="/static/assets/certificate-BqrY8JSR.js"></script>
{% endblock %}
