import{A as t,E as e,O as a,Z as s,_t as i,at as r,gt as o,lt as n,mt as d,pt as m,yt as u}from"./render-cqdoDfd9.js";import{r as p,t as x}from"./useThemeProps-DLDn3aDr.js";var h=u(i()),l=n(),c=s(),b=p("div",{name:"MuiContainer",slot:"Root",overridesResolver:(t,e)=>{const{ownerState:a}=t;return[e.root,e[`maxWidth${r(String(a.maxWidth))}`],a.fixed&&e.fixed,a.disableGutters&&e.disableGutters]}}),f=t=>x({props:t,name:"MuiContainer",defaultTheme:c}),g=(t,e)=>{const{classes:a,fixed:s,disableGutters:i,maxWidth:o}=t;return m({root:["root",o&&`maxWidth${r(String(o))}`,s&&"fixed",i&&"disableGutters"]},t=>d(e,t),a)};var W=function(t={}){const{createStyledComponent:e=b,useThemeProps:a=f,componentName:s="MuiContainer"}=t,i=e(({theme:t,ownerState:e})=>({width:"100%",marginLeft:"auto",boxSizing:"border-box",marginRight:"auto",...!e.disableGutters&&{paddingLeft:t.spacing(2),paddingRight:t.spacing(2),[t.breakpoints.up("sm")]:{paddingLeft:t.spacing(3),paddingRight:t.spacing(3)}}}),({theme:t,ownerState:e})=>e.fixed&&Object.keys(t.breakpoints.values).reduce((e,a)=>{const s=a,i=t.breakpoints.values[s];return 0!==i&&(e[t.breakpoints.up(s)]={maxWidth:`${i}${t.breakpoints.unit}`}),e},{}),({theme:t,ownerState:e})=>({..."xs"===e.maxWidth&&{[t.breakpoints.up("xs")]:{maxWidth:Math.max(t.breakpoints.values.xs,444)}},...e.maxWidth&&"xs"!==e.maxWidth&&{[t.breakpoints.up(e.maxWidth)]:{maxWidth:`${t.breakpoints.values[e.maxWidth]}${t.breakpoints.unit}`}}}));return h.forwardRef(function(t,e){const r=a(t),{className:n,component:d="div",disableGutters:m=!1,fixed:u=!1,maxWidth:p="lg",classes:x,...h}=r,c={...r,component:d,disableGutters:m,fixed:u,maxWidth:p};return(0,l.jsx)(i,{as:d,ownerState:c,className:o(g(c,s).root,n),ref:e,...h})})}({createStyledComponent:t("div",{name:"MuiContainer",slot:"Root",overridesResolver:(t,a)=>{const{ownerState:s}=t;return[a.root,a[`maxWidth${e(String(s.maxWidth))}`],s.fixed&&a.fixed,s.disableGutters&&a.disableGutters]}}),useThemeProps:t=>a({props:t,name:"MuiContainer"})});export{W as t};