import{lt as r,n as s,t as e}from"./render-cqdoDfd9.js";import"./modulepreload-polyfill-DgzdhEGd.js";import{t}from"./Box-pvlRBLzs.js";import{t as o}from"./Typography-8v555lWC.js";import{t as a}from"./Button-D-nJohaT.js";import{t as i}from"./Alert-BpUkH7Nx.js";import{t as n}from"./Layout-Bjk0lf1S.js";var m=r();e({children:(0,m.jsx)(()=>{const{successMessage:r,confirmationMessage:e,confirmUrl:c,errorMessage:l,ref:x,localeMessages:d}=s();return(0,m.jsx)(n,{children:l||e?e?(0,m.jsxs)(t,{sx:{my:6},children:[(0,m.jsx)(o,{variant:"h6",align:"center",sx:{mt:4,color:"text.primary"},children:e})," ",(0,m.jsx)(t,{mt:6,sx:{textAlign:"center"},children:(0,m.jsx)(a,{href:c,variant:"contained",mt:2,sx:{mx:"auto",px:3,fontSize:"1rem"},children:d.Confirm})})]}):(0,m.jsxs)(i,{severity:"error",sx:{maxWidth:800,margin:"20px auto"},children:[l," (ref: ",x,")"]}):(0,m.jsx)(i,{severity:"success",sx:{maxWidth:800,margin:"0 auto",backgroundColor:"background.light"},children:r})})},{})});