import{A as o,O as t,S as e,W as r,_t as i,gt as s,lt as a,mt as n,pt as d,yt as l}from"./render-cqdoDfd9.js";import{t as p}from"./Typography-8v555lWC.js";import{t as u}from"./DialogContext-CWuRPZWu.js";function v(o){return n("MuiDialogContent",o)}r("MuiDialogContent",["root","dividers"]);function c(o){return n("MuiDialogTitle",o)}var m=r("MuiDialogTitle",["root"]),f=l(i()),g=a(),x=o=>{const{classes:t,dividers:e}=o;return d({root:["root",e&&"dividers"]},v,t)},w=o("div",{name:"MuiDialogContent",slot:"Root",overridesResolver:(o,t)=>{const{ownerState:e}=o;return[t.root,e.dividers&&t.dividers]}})(e(({theme:o})=>({flex:"1 1 auto",WebkitOverflowScrolling:"touch",overflowY:"auto",padding:"20px 24px",variants:[{props:({ownerState:o})=>o.dividers,style:{padding:"16px 24px",borderTop:`1px solid ${(o.vars||o).palette.divider}`,borderBottom:`1px solid ${(o.vars||o).palette.divider}`}},{props:({ownerState:o})=>!o.dividers,style:{[`.${m.root} + &`]:{paddingTop:0}}}]}))),D=f.forwardRef(function(o,e){const r=t({props:o,name:"MuiDialogContent"}),{className:i,dividers:a=!1,...n}=r,d={...r,dividers:a};return(0,g.jsx)(w,{className:s(x(d).root,i),ownerState:d,ref:e,...n})}),M=o(p,{name:"MuiDialogTitle",slot:"Root"})({padding:"16px 24px",flex:"0 0 auto"}),S=f.forwardRef(function(o,e){const r=t({props:o,name:"MuiDialogTitle"}),{className:i,id:a,...n}=r,l=r,p=(o=>{const{classes:t}=o;return d({root:["root"]},c,t)})(l),{titleId:v=a}=f.useContext(u);return(0,g.jsx)(M,{component:"h2",className:s(p.root,i),ownerState:l,ref:e,variant:"h6",id:a??v,...n})});export{D as n,S as t};