{% extends "emails/base.html" %}
{% load i18n %}

{% block content %}

    <p class="email-paragraph">{% translate "Hello there," %}</p>

    <p class="email-paragraph">{% blocktranslate with course_title=course_title %}Congratulations on completing the course "{{ course_title }}"!{% endblocktranslate %}</p>

    <p class="email-paragraph">{% translate "To finalize your official Certificate of Completion, we need to verify how you would like your name to appear. Please follow the link below to submit your preferred name:" %}</p>

    <div class="email-cta-wrap">
        <a href="{{ link }}" class="email-cta bg-brand">
            {% translate "Submit Name" %}
        </a>
    </div>
    <p class="email-paragraph">
        {% translate "Best regards," %}<br />
        {% blocktranslate with organization_name=organization_name %}{{ organization_name }} Team{% endblocktranslate %}
    </p>

{% endblock %}
