import{P as e,U as r,lt as m}from"./render-cqdoDfd9.js";import{t as s}from"./useThemeProps-DLDn3aDr.js";import{c as a}from"./Paper-DtiadJnq.js";function h({props:m,name:a}){return s({props:m,name:a,defaultTheme:e,themeId:r})}var o=a((0,m().jsx)("path",{fillRule:"evenodd",d:"M13 9.5h5v-2h-5zm0 7h5v-2h-5zm6 4.5H5c-1.1 0-2-.9-2-2V5c0-1.1.9-2 2-2h14c1.1 0 2 .9 2 2v14c0 1.1-.9 2-2 2M6 11h5V6H6zm1-4h3v3H7zM6 18h5v-5H6zm1-4h3v3H7z"}),"Ballot");export{h as n,o as t};