{% extends "platform/base.html" %}

{% block extra_head %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-cqdoDfd9.js">
    <link rel="modulepreload" crossorigin href="/static/assets/modulepreload-polyfill-DgzdhEGd.js">
    <link rel="modulepreload" crossorigin href="/static/assets/preload-helper-w1h2GTnA.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Add-DhXv5sLw.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Base-CUv3vwU4.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Delete-BZeRDRIq.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Edit-Cm0FSuCS.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Alert-BpUkH7Nx.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Box-pvlRBLzs.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-D-nJohaT.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Dialog-BdfDhNhZ.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Grid-BiwBFfYj.js">
    <link rel="modulepreload" crossorigin href="/static/assets/IconButton-BkXELyri.js">
    <link rel="modulepreload" crossorigin href="/static/assets/LinearProgress-jZTkf1Z2.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Link-Bo4Kp619.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Paper-DtiadJnq.js">
    <link rel="modulepreload" crossorigin href="/static/assets/TableCell-DrJgogcq.js">
    <link rel="modulepreload" crossorigin href="/static/assets/TableContainer-FwpzIaZ5.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Typography-8v555lWC.js">
    <link rel="modulepreload" crossorigin href="/static/assets/utils-C0ZHLGh_.js">
    <script type="module" crossorigin src="/static/assets/organizations-Qb5oGPIC.js"></script>
{% endblock %}
