{% extends "emails/base.html" %}
{% load i18n %}

{% block content %}
        <p class="email-paragraph">{% translate "Hello there," %}</p>

        <p class="email-paragraph">
            {% blocktranslate %}Congratulations on enrolling in <strong>{{ course_title }}</strong>!{% endblocktranslate %}
            {% translate "We're excited to have you join our learning community." %}
        </p>

        <p class="email-paragraph">
            {% translate "To get started, please verify your email address by clicking the button below:" %}
        </p>

        <div class="email-cta-wrap">
            <a href="{{ verification_link }}" class="email-cta bg-brand">
                {% translate "Verify Your Email Address" %}
            </a>
        </div>

        {% if support_imap_interface %}
        <div class="email-panel border-brand">
            <h4 class="color-brand" style="margin-top: 0;">{% translate "Alternative Verification Method" %}</h4>
            <p class="email-paragraph" style="margin-bottom: 15px;">
                {% blocktranslate %}You can also verify your email by sending a message to <strong style="color: #495057;">{{ imap_email_address }}</strong>{% endblocktranslate %}
                {% translate "with your verification code in the subject line or email body." %}
                {% translate "Simply forward this email to complete the verification process." %}
            </p>
            <p class="email-code-box">
                {% translate "Verification Code:" %}
                <span style="font-family: 'Courier New', monospace; font-size: 18px; font-weight: bold;">{{ verification_code }}</span>
            </p>
        </div>
        {% endif %}

        <div class="email-divider-note">
            <p>{% translate "If you didn't sign up for this course, you can safely ignore this email." %}</p>
        </div>

        <p class="email-paragraph">{% translate "Best regards," %}<br>
        {% blocktranslate %}The {{ organization_name }} Team{% endblocktranslate %}</p>
{% endblock %}
