{% extends "personalised/base.html" %}

{% block head_script %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-cqdoDfd9.js">
    <link rel="modulepreload" crossorigin href="/static/assets/modulepreload-polyfill-DgzdhEGd.js">
    <link rel="modulepreload" crossorigin href="/static/assets/WorkspacePremium-BuOxKl4p.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Alert-BpUkH7Nx.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Box-pvlRBLzs.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-D-nJohaT.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Container-DQi3l0z9.js">
    <link rel="modulepreload" crossorigin href="/static/assets/TextField-CbQ6hH_9.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Typography-8v555lWC.js">
    <script type="module" crossorigin src="/static/assets/certtificate_form-BXJC62MV.js"></script>
{% endblock %}
