var t=t=>{let e=null;if(document.cookie&&""!==document.cookie){const o=document.cookie.split(";");for(let n=0;n<o.length;n++){const c=o[n].trim();if(c.substring(0,t.length+1)===t+"="){e=decodeURIComponent(c.substring(t.length+1));break}}}return e};export{t};