import{T as r,lt as o}from"./render-cqdoDfd9.js";import{t as e}from"./Box-pvlRBLzs.js";import{t as n}from"./Container-DQi3l0z9.js";import{t as a}from"./Typography-8v555lWC.js";import{t}from"./Link-Bo4Kp619.js";var i=o(),s=({children:o})=>(0,i.jsxs)(i.Fragment,{children:[(0,i.jsx)(r,{styles:r=>({body:{margin:0,padding:0,backgroundColor:r.palette.background.dark,color:r.palette.text.primary}})}),(0,i.jsx)(n,{sx:{backgroundColor:"background.paper",padding:4,marginTop:{xs:0,md:"32px"},borderRadius:2,boxShadow:2},children:o}),(0,i.jsx)(e,{component:"footer",sx:{position:"fixed",bottom:0,right:16,padding:1,zIndex:1e3,backgroundColor:"transparent"},children:(0,i.jsxs)(a,{variant:"caption",sx:{color:"text.secondary",fontSize:"0.7rem",opacity:.8},children:["Powered by"," ",(0,i.jsx)(t,{href:"https://github.com/AvaCodeSolutions/django-email-learning",target:"_blank",rel:"noopener noreferrer",sx:{color:"primary.main",textDecoration:"none","&:hover":{textDecoration:"underline"}},children:"Django Email Learning"})]})})]});export{s as t};