import{G as e,J as n,q as o}from"./render-cqdoDfd9.js";var t=n();function s(e){const{theme:n,name:t,props:s}=e;return n&&n.components&&n.components[t]&&n.components[t].defaultProps?o(n.components[t].defaultProps,s):s}function r({props:n,name:o,defaultTheme:t,themeId:r}){let p=e(t);return r&&(p=p[r]||p),s({theme:p,name:o,props:n})}export{s as n,t as r,r as t};