{% extends "public/base.html" %}
{% load i18n %}

{% block head_script %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-cqdoDfd9.js">
    <link rel="modulepreload" crossorigin href="/static/assets/modulepreload-polyfill-DgzdhEGd.js">
    <link rel="modulepreload" crossorigin href="/static/assets/CheckCircle-BNiu1Y1V.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Box-pvlRBLzs.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-D-nJohaT.js">
    <link rel="modulepreload" crossorigin href="/static/assets/EnrollmentForm-BMy8fifs.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Stack-BIWjPMOZ.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Container-DQi3l0z9.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Dialog-BdfDhNhZ.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Select-BbgK42y1.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Link-Bo4Kp619.js">
    <link rel="modulepreload" crossorigin href="/static/assets/ListItemText-sOEvzNqg.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Paper-DtiadJnq.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Typography-8v555lWC.js">
    <link rel="modulepreload" crossorigin href="/static/assets/isMuiElement-BOXXIqCm.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Layout-Bjk0lf1S.js">
    <link rel="modulepreload" crossorigin href="/static/assets/RequiredTextField-P1YoYBsM.js">
    <script type="module" crossorigin src="/static/assets/public_course-DJF8zxSg.js"></script>
    {% if json_ld %}
    <script type="application/ld+json">{{ json_ld|safe }}</script>
    {% endif %}
{% endblock %}
{% block meta_tags %}
    <meta name="description" content="{{ course_description }}">
    <meta property="og:type" content="website">
    <meta property="og:url" content="{{ request.build_absolute_uri }}">
    <meta property="og:title" content="{{ course_title }}">
    {% if course_description %}<meta property="og:description" content="{{ course_description }}">{% endif %}
    {% if course_image_url %}<meta property="og:image" content="{{ course_image_url }}">{% endif %}

    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:title" content="{{ course_title }}">
    {% if course_description %}<meta name="twitter:description" content="{{ course_description }}">{% endif %}
    {% if course_image_url %}<meta name="twitter:image" content="{{ course_image_url }}">{% endif %}
{% endblock %}
