import{A as t,E as r,O as a,S as e,W as o,_t as n,gt as i,lt as p,mt as s,pt as l,w as h,x as g,yt as y}from"./render-cqdoDfd9.js";function m(t){return s("MuiTypography",t)}var c=o("MuiTypography",["root","h1","h2","h3","h4","h5","h6","subtitle1","subtitle2","body1","body2","inherit","button","caption","overline","alignLeft","alignRight","alignCenter","alignJustify","noWrap","gutterBottom","paragraph"]),u=y(n()),v=p(),f={primary:!0,secondary:!0,error:!0,info:!0,success:!0,warning:!0,textPrimary:!0,textSecondary:!0,textDisabled:!0},b=h(),d=t=>{const{align:a,gutterBottom:e,noWrap:o,paragraph:n,variant:i,classes:p}=t;return l({root:["root",i,"inherit"!==t.align&&`align${r(a)}`,e&&"gutterBottom",o&&"noWrap",n&&"paragraph"]},m,p)},w=t("span",{name:"MuiTypography",slot:"Root",overridesResolver:(t,a)=>{const{ownerState:e}=t;return[a.root,e.variant&&a[e.variant],"inherit"!==e.align&&a[`align${r(e.align)}`],e.noWrap&&a.noWrap,e.gutterBottom&&a.gutterBottom,e.paragraph&&a.paragraph]}})(e(({theme:t})=>({margin:0,variants:[{props:{variant:"inherit"},style:{font:"inherit",lineHeight:"inherit",letterSpacing:"inherit"}},...Object.entries(t.typography).filter(([t,r])=>"inherit"!==t&&r&&"object"==typeof r).map(([t,r])=>({props:{variant:t},style:r})),...Object.entries(t.palette).filter(g()).map(([r])=>({props:{color:r},style:{color:(t.vars||t).palette[r].main}})),...Object.entries(t.palette?.text||{}).filter(([,t])=>"string"==typeof t).map(([a])=>({props:{color:`text${r(a)}`},style:{color:(t.vars||t).palette.text[a]}})),{props:({ownerState:t})=>"inherit"!==t.align,style:{textAlign:"var(--Typography-textAlign)"}},{props:({ownerState:t})=>t.noWrap,style:{overflow:"hidden",textOverflow:"ellipsis",whiteSpace:"nowrap"}},{props:({ownerState:t})=>t.gutterBottom,style:{marginBottom:"0.35em"}},{props:({ownerState:t})=>t.paragraph,style:{marginBottom:16}}]}))),x={h1:"h1",h2:"h2",h3:"h3",h4:"h4",h5:"h5",h6:"h6",subtitle1:"h6",subtitle2:"h6",body1:"p",body2:"p",inherit:"p"},B=u.forwardRef(function(t,r){const{color:e,...o}=a({props:t,name:"MuiTypography"}),n=b({...o,...!f[e]&&{color:e}}),{align:p="inherit",className:s,component:l,gutterBottom:h=!1,noWrap:g=!1,paragraph:y=!1,variant:m="body1",variantMapping:c=x,...u}=n,B={...n,align:p,color:e,className:s,component:l,gutterBottom:h,noWrap:g,paragraph:y,variant:m,variantMapping:c};return(0,v.jsx)(w,{as:l||(y?"p":c[m]||x[m])||"span",ref:r,className:i(d(B).root,s),...u,ownerState:B,style:{..."inherit"!==p&&{"--Typography-textAlign":p},...u.style}})});export{c as n,B as t};