.container_855a57{--uib-dot-size:calc(var(--uib-size) * .4);height:var(--uib-size);width:var(--uib-size);flex-shrink:0;justify-content:center;align-items:center;display:inline-flex}.inner_eef15b{height:var(--uib-size);width:var(--uib-size);animation:rotate_57bfe8 calc(var(--uib-speed) * 1.667) infinite linear;justify-content:center;align-items:center;display:flex;position:relative}.inner_eef15b:before,.inner_eef15b:after{content:"";height:var(--uib-dot-size);width:var(--uib-dot-size);background-color:var(--uib-color);border-radius:50%;flex-shrink:0;transition:background-color .3s;position:absolute}.inner_eef15b:before{animation:orbit_60733f var(--uib-speed) linear infinite}.inner_eef15b:after{animation:orbit_60733f var(--uib-speed) linear calc(var(--uib-speed) / -2) infinite}@keyframes rotate_57bfe8{0%{transform:rotate(0)}to{transform:rotate(360deg)}}@keyframes orbit_60733f{0%{transform:translateX(calc(var(--uib-size) * .25)) scale(.73684);opacity:.65}5%{transform:translateX(calc(var(--uib-size) * .235)) scale(.684208);opacity:.58}10%{transform:translateX(calc(var(--uib-size) * .182)) scale(.631576);opacity:.51}15%{transform:translateX(calc(var(--uib-size) * .129)) scale(.578944);opacity:.44}20%{transform:translateX(calc(var(--uib-size) * .076)) scale(.526312);opacity:.37}25%{opacity:.3;transform:translate(0%)scale(.47368)}30%{transform:translateX(calc(var(--uib-size) * -.076)) scale(.526312);opacity:.37}35%{transform:translateX(calc(var(--uib-size) * -.129)) scale(.578944);opacity:.44}40%{transform:translateX(calc(var(--uib-size) * -.182)) scale(.631576);opacity:.51}45%{transform:translateX(calc(var(--uib-size) * -.235)) scale(.684208);opacity:.58}50%{transform:translateX(calc(var(--uib-size) * -.25)) scale(.73684);opacity:.65}55%{transform:translateX(calc(var(--uib-size) * -.235)) scale(.789472);opacity:.72}60%{transform:translateX(calc(var(--uib-size) * -.182)) scale(.842104);opacity:.79}65%{transform:translateX(calc(var(--uib-size) * -.129)) scale(.894736);opacity:.86}70%{transform:translateX(calc(var(--uib-size) * -.076)) scale(.947368);opacity:.93}75%{opacity:1;transform:translate(0%)scale(1)}80%{transform:translateX(calc(var(--uib-size) * .076)) scale(.947368);opacity:.93}85%{transform:translateX(calc(var(--uib-size) * .129)) scale(.894736);opacity:.86}90%{transform:translateX(calc(var(--uib-size) * .182)) scale(.842104);opacity:.79}95%{transform:translateX(calc(var(--uib-size) * .235)) scale(.789472);opacity:.72}to{transform:translateX(calc(var(--uib-size) * .25)) scale(.73684);opacity:.65}}
