import{A as e,O as t,S as a,W as s,_t as o,g as r,gt as i,j as n,lt as d,mt as l,pt as p,s as c,yt as u}from"./render-cqdoDfd9.js";import{f as m,o as v}from"./Select-BbgK42y1.js";import{i as g,n as b}from"./listItemTextClasses-vsX2DYjS.js";function f(e){return l("MuiDivider",e)}var h=s("MuiDivider",["root","absolute","fullWidth","inset","middle","flexItem","light","vertical","withChildren","withChildrenVertical","textAlignRight","textAlignLeft","wrapper","wrapperVertical"]);function y(e){return l("MuiMenuItem",e)}var x=s("MuiMenuItem",["root","focusVisible","dense","disabled","divider","gutters","selected"]),$=u(o()),C=d(),w=e(c,{shouldForwardProp:e=>n(e)||"classes"===e,name:"MuiMenuItem",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:a}=e;return[t.root,a.dense&&t.dense,a.divider&&t.divider,!a.disableGutters&&t.gutters]}})(a(({theme:e})=>({...e.typography.body1,display:"flex",justifyContent:"flex-start",alignItems:"center",position:"relative",textDecoration:"none",minHeight:48,paddingTop:6,paddingBottom:6,boxSizing:"border-box",whiteSpace:"nowrap","&:hover":{textDecoration:"none",backgroundColor:(e.vars||e).palette.action.hover,"@media (hover: none)":{backgroundColor:"transparent"}},[`&.${x.selected}`]:{backgroundColor:e.alpha((e.vars||e).palette.primary.main,(e.vars||e).palette.action.selectedOpacity),[`&.${x.focusVisible}`]:{backgroundColor:e.alpha((e.vars||e).palette.primary.main,`${(e.vars||e).palette.action.selectedOpacity} + ${(e.vars||e).palette.action.focusOpacity}`)}},[`&.${x.selected}:hover`]:{backgroundColor:e.alpha((e.vars||e).palette.primary.main,`${(e.vars||e).palette.action.selectedOpacity} + ${(e.vars||e).palette.action.hoverOpacity}`),"@media (hover: none)":{backgroundColor:e.alpha((e.vars||e).palette.primary.main,(e.vars||e).palette.action.selectedOpacity)}},[`&.${x.focusVisible}`]:{backgroundColor:(e.vars||e).palette.action.focus},[`&.${x.disabled}`]:{opacity:(e.vars||e).palette.action.disabledOpacity},[`& + .${h.root}`]:{marginTop:e.spacing(1),marginBottom:e.spacing(1)},[`& + .${h.inset}`]:{marginLeft:52},[`& .${b.root}`]:{marginTop:0,marginBottom:0},[`& .${b.inset}`]:{paddingLeft:36},[`& .${g.root}`]:{minWidth:36},variants:[{props:({ownerState:e})=>!e.disableGutters,style:{paddingLeft:16,paddingRight:16}},{props:({ownerState:e})=>e.divider,style:{borderBottom:`1px solid ${(e.vars||e).palette.divider}`,backgroundClip:"padding-box"}},{props:({ownerState:e})=>!e.dense,style:{[e.breakpoints.up("sm")]:{minHeight:"auto"}}},{props:({ownerState:e})=>e.dense,style:{minHeight:32,paddingTop:4,paddingBottom:4,...e.typography.body2,[`& .${g.root} svg`]:{fontSize:"1.25rem"}}}]}))),M=$.forwardRef(function(e,a){const s=t({props:e,name:"MuiMenuItem"}),{autoFocus:o=!1,component:n="li",dense:d=!1,divider:l=!1,disableGutters:c=!1,focusVisibleClassName:u,role:g="menuitem",tabIndex:b,className:f,...h}=s,x=$.useContext(v),M=$.useMemo(()=>({dense:d||x.dense||!1,disableGutters:c}),[x.dense,d,c]),S=$.useRef(null);m(()=>{o&&S.current&&S.current.focus()},[o]);const k={...s,dense:M.dense,divider:l,disableGutters:c},I=(e=>{const{disabled:t,dense:a,divider:s,disableGutters:o,selected:r,classes:i}=e,n=p({root:["root",a&&"dense",t&&"disabled",!o&&"gutters",s&&"divider",r&&"selected"]},y,i);return{...i,...n}})(s),O=r(S,a);let V;return s.disabled||(V=void 0!==b?b:-1),(0,C.jsx)(v.Provider,{value:M,children:(0,C.jsx)(w,{ref:O,role:g,tabIndex:V,component:n,focusVisibleClassName:i(I.focusVisible,u),className:i(I.root,f),...h,ownerState:k,classes:I})})});export{f as n,M as t};