import{A as o,O as t,W as a,_t as e,gt as r,lt as n,mt as s,pt as i,yt as c}from"./render-cqdoDfd9.js";function l(o){return s("MuiTableContainer",o)}a("MuiTableContainer",["root"]);var u=c(e()),m=n(),f=o=>{const{classes:t}=o;return i({root:["root"]},l,t)},p=o("div",{name:"MuiTableContainer",slot:"Root"})({width:"100%",overflowX:"auto"}),d=u.forwardRef(function(o,a){const e=t({props:o,name:"MuiTableContainer"}),{className:n,component:s="div",...i}=e,c={...e,component:s};return(0,m.jsx)(p,{ref:a,as:s,className:r(f(c).root,n),ownerState:c,...i})});export{d as t};