import{A as t,O as o,W as a,_t as s,gt as r,j as e,lt as n,mt as c,pt as i,yt as l}from"./render-cqdoDfd9.js";import{t as m}from"./Typography-8v555lWC.js";function p(t){return c("MuiDialogContentText",t)}a("MuiDialogContentText",["root"]);var u=l(s()),d=n(),f=t(m,{shouldForwardProp:t=>e(t)||"classes"===t,name:"MuiDialogContentText",slot:"Root"})({}),x=u.forwardRef(function(t,a){const s=o({props:t,name:"MuiDialogContentText"}),{children:e,className:n,...c}=s,l=(t=>{const{classes:o}=t,a=i({root:["root"]},p,o);return{...o,...a}})(c);return(0,d.jsx)(f,{component:"p",variant:"body1",color:"textSecondary",ref:a,ownerState:c,className:r(l.root,n),...s,classes:l})});export{x as t};