{% extends "emails/base.html" %}
{% load i18n %}

{% block content %}
    <h2 class="email-title">{{ quiz.title }}</h2>

    <p class="email-paragraph">{% translate "Hello there," %}</p>

    <p class="email-paragraph">{% blocktranslate with deadline_days=quiz.deadline_days %}Your quiz is now available for completion. You have <strong>{{ deadline_days }} days</strong> from today to submit your responses.{% endblocktranslate %}</p>

    <p class="email-paragraph">{% blocktranslate with score=quiz.required_score %}To successfully pass this quiz, you must achieve a minimum score of <strong>{{ score }}</strong>.{% endblocktranslate %}</p>
    <p class="email-paragraph">{% translate "Please click the link below to access and submit your quiz:" %}</p>

    <div class="email-cta-wrap">
        <a href="{{ link }}" class="email-cta bg-brand">
            {% translate "Start Quiz" %}
        </a>
    </div>
    <p class="email-paragraph">{% translate "Best of luck!" %}</p>
    <p class="email-muted-note">
        {% blocktranslate %}If you wish to unsubscribe from this course, please <a href="{{ unsubscribe_link }}" class="color-brand" style="text-decoration: none;">click here</a>{% endblocktranslate %}.
    </p>
{% endblock %}
