{% extends "personalised/base.html" %}

{% block head_script %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-cqdoDfd9.js">
    <link rel="modulepreload" crossorigin href="/static/assets/modulepreload-polyfill-DgzdhEGd.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Alert-BpUkH7Nx.js">
    <link rel="modulepreload" crossorigin href="/static/assets/formControlState-ClbFzec2.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Box-pvlRBLzs.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-D-nJohaT.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Dialog-BdfDhNhZ.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Paper-DtiadJnq.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Typography-8v555lWC.js">
    <link rel="modulepreload" crossorigin href="/static/assets/SwitchBase-CiaJBIGW.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Layout-Bjk0lf1S.js">
    <script type="module" crossorigin src="/static/assets/quiz_public-Dw2SUMLi.js"></script>
{% endblock %}
