{% extends "emails/base.html" %}
{% load i18n %}

{% block content %}
<h2 class="email-title">{% blocktranslate %}Welcome to {{ organization }}{% endblocktranslate %}</h2>
<p class="email-paragraph">{% translate "Hello there," %}</p>

<p class="email-paragraph">{% blocktranslate %}
You have been added as a user to the {{ organization }} platform.
To get started and set up your account, please click the link below to choose your password.
{% endblocktranslate %}</p>

{% block reset_link %}
{{ protocol }}://{{ domain }}{% url 'password_reset_confirm' uidb64=uid token=token %}
{% endblock %}

<p class="email-paragraph">{% translate "If you weren't expecting this invitation, you can safely ignore this email." %}</p>
<p class="email-paragraph">{% translate "Best regards," %}<br/>
{% blocktranslate %}The {{ organization }} Team{% endblocktranslate %}</p>
{% endblock %}
