{% extends "platform/base.html" %}

{% block extra_head %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-cqdoDfd9.js">
    <link rel="modulepreload" crossorigin href="/static/assets/modulepreload-polyfill-DgzdhEGd.js">
    <link rel="modulepreload" crossorigin href="/static/assets/preload-helper-w1h2GTnA.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Ballot-8uQIfReY.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Base-CUv3vwU4.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Delete-BZeRDRIq.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Alert-BpUkH7Nx.js">
    <link rel="modulepreload" crossorigin href="/static/assets/formControlState-ClbFzec2.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Box-pvlRBLzs.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-D-nJohaT.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Dialog-BdfDhNhZ.js">
    <link rel="modulepreload" crossorigin href="/static/assets/DialogActions-IskUXpPi.js">
    <link rel="modulepreload" crossorigin href="/static/assets/DialogTitle-HCb6VQhm.js">
    <link rel="modulepreload" crossorigin href="/static/assets/MenuItem-CsbWpzKb.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Select-BbgK42y1.js">
    <link rel="modulepreload" crossorigin href="/static/assets/TextField-CbQ6hH_9.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Grid-BiwBFfYj.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Grow-g9iGpiDr.js">
    <link rel="modulepreload" crossorigin href="/static/assets/IconButton-BkXELyri.js">
    <link rel="modulepreload" crossorigin href="/static/assets/LinearProgress-jZTkf1Z2.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Paper-DtiadJnq.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Tooltip-BI9A-Ujn.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Switch-Cxv-30sM.js">
    <link rel="modulepreload" crossorigin href="/static/assets/TableCell-DrJgogcq.js">
    <link rel="modulepreload" crossorigin href="/static/assets/TableContainer-FwpzIaZ5.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Typography-8v555lWC.js">
    <link rel="modulepreload" crossorigin href="/static/assets/utils-C0ZHLGh_.js">
    <link rel="stylesheet" href="/static/assets/course-CYb_xK7B.css">
    <script type="module" crossorigin src="/static/assets/course-DxBCeKjg.js"></script>
    {% if appContext.customComponent %}
        {% if appContext.customComponent.script_url %}
            <script src="{{ appContext.customComponent.script_url }}"></script>
        {% endif %}
        {% if appContext.customComponent.style_url %}
            <link rel="stylesheet" href="{{ appContext.customComponent.style_url }}">
        {% endif %}
    {% endif %}
{% endblock %}
